//>>built
define("dojo/nls/pmbdojo_pt-br",{"dijit/form/nls/validate":{invalidMessage:"O valor inserido n\u00e3o \u00e9 v\u00e1lido.",missingMessage:"Este valor \u00e9 necess\u00e1rio.",rangeMessage:"Este valor est\u00e1 fora do intervalo. ",_localized:{}},"dojo/cldr/nls/number":{scientificFormat:"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]",infinity:"\u221e",superscriptingExponent:"\u00d7",list:";",percentSign:"%",minusSign:"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000\u00a0tri",
"currencySpacing-afterCurrency-insertBetween":"\u00a0",nan:"NaN",plusSign:"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]",currencyFormat:"\u00a4#,##0.00;(\u00a4#,##0.00)",perMille:"\u2030",group:".",percentFormat:"#,##0%","decimalFormat-long":"000 trilh\u00f5es",decimalFormat:"#,##0.###",decimal:",","currencySpacing-beforeCurrency-insertBetween":"\u00a0",exponential:"E",_localized:{}},"dijit/form/nls/ComboBox":{previousMessage:"Op\u00e7\u00f5es anteriores",
nextMessage:"Mais op\u00e7\u00f5es",_localized:{}},"dijit/nls/loading":{loadingState:"Carregando...",errorState:"Desculpe, ocorreu um erro",_localized:{}},"dijit/nls/common":{buttonOk:"OK",buttonCancel:"Cancelar",buttonSave:"Salvar",itemClose:"Fechar",_localized:{}},"dijit/_editor/nls/commands":{bold:"Negrito",copy:"Copiar",cut:"Recortar","delete":"Excluir",indent:"Recuar",insertHorizontalRule:"R\u00e9gua Horizontal",insertOrderedList:"Lista Numerada",insertUnorderedList:"Lista com Marcadores",italic:"It\u00e1lico",
justifyCenter:"Alinhar pelo Centro",justifyFull:"Justificar",justifyLeft:"Alinhar pela Esquerda",justifyRight:"Alinhar pela Direita",outdent:"N\u00e3o-chanfrado",paste:"Colar",redo:"Refazer",removeFormat:"Remover Formato",selectAll:"Selecionar Todos",strikethrough:"Tachado",subscript:"Subscrito",superscript:"Sobrescrito",underline:"Sublinhado",undo:"Desfazer",unlink:"Remover Link",createLink:"Criar Link",toggleDir:"Comutar Dire\u00e7\u00e3o",insertImage:"Inserir Imagem",insertTable:"Inserir/Editar Tabela",
toggleTableBorder:"Alternar Moldura da Tabela",deleteTable:"Excluir Tabela",tableProp:"Propriedade da Tabela",htmlToggle:"Origem HTML",foreColor:"Cor do Primeiro Plano",hiliteColor:"Cor de segundo plano",plainFormatBlock:"Estilo de Par\u00e1grafo",formatBlock:"Estilo de Par\u00e1grafo",fontSize:"Tamanho da Fonte",fontName:"Nome da Fonte",tabIndent:"Recuo de Guia",fullScreen:"Comutar Tela Cheia",viewSource:"Visualizar Origem HTML",print:"Impress\u00e3o",newPage:"Nova P\u00e1gina",systemShortcut:'A a\u00e7\u00e3o "${0}" est\u00e1 dispon\u00edvel em seu navegador apenas usando um atalho do teclado. Use ${1}.',
ctrlKey:"ctrl+${0}",appleKey:"\u2318${0}",_localized:{}},"dijit/_editor/nls/FontChoice":{1:"extra-extra-pequeno",2:"extra-pequeno",3:"pequena",4:"m\u00e9dio",5:"grande",6:"extra-grande",7:"extra-extra-grande",fontSize:"Tamanho",fontName:"Fonte",formatBlock:"Formatar",serif:"serif","sans-serif":"sans-serif",monospace:"espa\u00e7o simples",cursive:"cursiva",fantasy:"fantasy",noFormat:"Nenhum",p:"Par\u00e1grafo",h1:"T\u00edtulo",h2:"Subt\u00edtulo",h3:"Sub-subt\u00edtulo",pre:"Pr\u00e9-formatado",_localized:{}},
"dojox/editor/plugins/nls/latinEntities":{iexcl:"ponto de exclama\u00e7\u00e3o invertido",cent:"s\u00edmbolo de centavo",pound:"s\u00edmbolo de libra",curren:"s\u00edmbolo de moeda",yen:"s\u00edmbolo de ienes\u00edmbolo de yuan",brvbar:"barra interrompida\nbarra vertical interrompida",sect:"s\u00edmbolo de se\u00e7\u00e3o",uml:"trema\ntrema de espa\u00e7amento",copy:"s\u00edmbolo de copyright",ordf:"indicador ordinal feminino",laquo:"aspas latinas duplas de encerramento\ns\u00edmbolo de cita\u00e7\u00e3o esquerdo",
not:"nenhum s\u00edmbolo",shy:"h\u00edfen reformat\u00e1vel\nh\u00edfen discricion\u00e1rio",reg:"s\u00edmbolo de marca registrada\ns\u00edmbolo de marca comercial registrada",macr:"macro\nmacro de espa\u00e7amento\nsobrelinha\nsobrebarra APL",deg:"s\u00edmbolo de grau",plusmn:"s\u00edmbolo de mais e menos\ns\u00edmbolo de mais ou menos",sup2:"sobrescrito dois\nd\u00edgito sobrescrito dois\nquadrado",sup3:"sobrescrito tr\u00eas\nd\u00edgito sobrescrito tr\u00eas\nem cubo",acute:"acento agudo\nagudo para espa\u00e7amento",
micro:"s\u00edmbolo de micro",para:"s\u00edmbolo p\u00e9-de-mosca\ns\u00edmbolo de par\u00e1grafo",middot:"ponto do meio\nv\u00edrgula Georgiana\nponto do meio grego",cedil:"cedilha\ncedilha de espa\u00e7amento",sup1:"sobrescrito um\nd\u00edgito sobrescrito um",ordm:"indicador ordinal masculino",raquo:"aspas latinas duplas de abertura\ns\u00edmbolo de cita\u00e7\u00e3o direito",frac14:"fra\u00e7\u00e3o de um quarto comum\nfra\u00e7\u00e3o de um quarto",frac12:"fra\u00e7\u00e3o de um meio comum\nfra\u00e7\u00e3o de um meio",
frac34:"fra\u00e7\u00e3o de tr\u00eas quartos comum\nfra\u00e7\u00e3o de tr\u00eas quartos",iquest:"ponto de interroga\u00e7\u00e3o invertido\nponto de interroga\u00e7\u00e3o invertido",Agrave:"Letra latina mai\u00fascula A com acento grave\nletra latina mai\u00fascula A com acento grave",Aacute:"Letra latina mai\u00fascula A com acento agudo",Acirc:"Letra latina mai\u00fascula A com acento circunflexo",Atilde:"Letra latina mai\u00fascula A com til",Auml:"Letra latina mai\u00fascula A com trema",
Aring:"Letra latina mai\u00fascula A com c\u00edrculo em cima\nLetra latina mai\u00fascula A com c\u00edrculo",AElig:"Letra latina mai\u00fascula AE\nLetra latina mai\u00fascula AE",Ccedil:"Letra latina mai\u00fascula C com cedilha",Egrave:"Letra latina mai\u00fascula E com acento grave",Eacute:"Letra latina mai\u00fascula E com acento agudo",Ecirc:"Letra latina mai\u00fascula E com acento circunflexo",Euml:"Letra latina mai\u00fascula E com trema",Igrave:"Letra latina mai\u00fascula I com acento grave",
Iacute:"Letra latina mai\u00fascula I com acento agudo",Icirc:"Letra latina mai\u00fascula I com acento circunflexo",Iuml:"Letra latina mai\u00fascula I com trema",ETH:"Letra latina mai\u00fascula ETH",Ntilde:"Letra latina mai\u00fascula N com til",Ograve:"Letra latina mai\u00fascula O com acento grave",Oacute:"Letra latina mai\u00fascula O com acento agudo",Ocirc:"Letra latina mai\u00fascula O com acento circunflexo",Otilde:"Letra latina mai\u00fascula O com til",Ouml:"Letra latina mai\u00fascula O com trema",
times:"s\u00edmbolo de multiplica\u00e7\u00e3o",Oslash:"Letra latina mai\u00fascula O tra\u00e7ada\nLetra latina mai\u00fascula O cortada com barra",Ugrave:"Letra latina mai\u00fascula U com acento grave",Uacute:"Letra latina mai\u00fascula U com acento agudo",Ucirc:"Letra latina mai\u00fascula U com acento circunflexo",Uuml:"Letra latina mai\u00fascula U com trema",Yacute:"Letra latina mai\u00fascula Y com acento agudo",THORN:"Letra latina mai\u00fascula THORN",szlig:"Letra latina min\u00fascula scharfes s\ness-zed",
agrave:"Letra latina min\u00fascula a com acento grave\nletra latina min\u00fascula a com acento grave",aacute:"Letra latina min\u00fascula a com acento agudo",acirc:"Letra latina min\u00fascula a com acento circunflexo",atilde:"Letra latina min\u00fascula a com til",auml:"Letra latina min\u00fascula a com trema",aring:"Letra latina min\u00fascula a com c\u00edrculo em cima\nLetra latina min\u00fascula a com c\u00edrculo",aelig:"Letra latina min\u00fascula ae\nLetra latina min\u00fascula ae contra\u00edda",
ccedil:"Letra latina min\u00fascula c com cedilha",egrave:"Letra latina min\u00fascula e com acento grave",eacute:"Letra latina min\u00fascula e com acento agudo",ecirc:"Letra latina min\u00fascula e com acento circunflexo",euml:"Letra latina min\u00fascula e com trema",igrave:"Letra latina min\u00fascula i com acento grave",iacute:"Letra latina min\u00fascula i com acento agudo",icirc:"Letra latina min\u00fascula i com acento circunflexo",iuml:"Letra latina min\u00fascula i com trema",eth:"Letra latina min\u00fascula eth",
ntilde:"Letra latina min\u00fascula n com til",ograve:"Letra latina min\u00fascula o com acento grave",oacute:"Letra latina min\u00fascula o com acento agudo",ocirc:"Letra latina min\u00fascula o com acento circunflexo",otilde:"Letra latina min\u00fascula o com til",ouml:"Letra latina min\u00fascula o com trema",divide:"s\u00edmbolo de divis\u00e3o",oslash:"Letra latina min\u00fascula o tra\u00e7ada\nLetra latina min\u00fascula o cortada com barra",ugrave:"Letra latina min\u00fascula u com acento grave",
uacute:"Letra latina min\u00fascula u com acento agudo",ucirc:"Letra latina min\u00fascula u com acento circunflexo",uuml:"Letra latina min\u00fascula u com trema",yacute:"Letra latina min\u00fascula y com acento agudo",thorn:"Letra latina min\u00fascula thorn",yuml:"Letra latina min\u00fascula y com trema",fnof:"Letra latina min\u00fascula f com gancho\nfun\u00e7\u00e3o\nflorim",Alpha:"Letra grega mai\u00fascula alfa",Beta:"Letra grega mai\u00fascula beta",Gamma:"Letra grega mai\u00fascula gama",
Delta:"Letra grega mai\u00fascula delta",Epsilon:"Letra grega mai\u00fascula \u00e9psilon",Zeta:"Letra grega mai\u00fascula zeta",Eta:"Letra grega mai\u00fascula eta",Theta:"Letra grega mai\u00fascula teta",Iota:"Letra grega mai\u00fascula iota",Kappa:"Letra grega mai\u00fascula capa",Lambda:"Letra grega mai\u00fascula lambda",Mu:"Letra grega mai\u00fascula miu",Nu:"Letra grega mai\u00fascula nu",Xi:"Letra grega mai\u00fascula ksi",Omicron:"Letra grega mai\u00fascula \u00f3micron",Pi:"Letra grega mai\u00fascula pi",
Rho:"Letra grega mai\u00fascula r\u00f4",Sigma:"Letra grega mai\u00fascula sigma",Tau:"Letra grega mai\u00fascula tau",Upsilon:"Letra grega mai\u00fascula upsilon",Phi:"Letra grega mai\u00fascula fi",Chi:"Letra grega mai\u00fascula chi",Psi:"Letra grega mai\u00fascula psi",Omega:"Letra grega mai\u00fascula \u00f4mega",alpha:"Letra grega min\u00fascula alfa",beta:"Letra grega min\u00fascula beta",gamma:"Letra grega min\u00fascula gama",delta:"Letra grega min\u00fascula delta",epsilon:"Letra grega min\u00fascula \u00e9psilon",
zeta:"Letra grega min\u00fascula zeta",eta:"Letra grega min\u00fascula eta",theta:"Letra grega min\u00fascula teta",iota:"Letra grega min\u00fascula iota",kappa:"Letra grega min\u00fascula capa",lambda:"Letra grega min\u00fascula lambda",mu:"Letra grega min\u00fascula miu",nu:"Letra grega min\u00fascula nu",xi:"Letra grega min\u00fascula ksi",omicron:"Letra grega min\u00fascula \u00f3micron",pi:"Letra grega min\u00fascula pi",rho:"Letra grega min\u00fascula r\u00f4",sigmaf:"Letra grega min\u00fascula sigma final",
sigma:"Letra grega min\u00fascula sigma",tau:"Letra grega min\u00fascula tau",upsilon:"Letra grega min\u00fascula upsilon",phi:"Letra grega min\u00fascula fi",chi:"Letra grega min\u00fascula chi",psi:"Letra grega min\u00fascula psi",omega:"Letra grega min\u00fascula \u00f4mega",thetasym:"S\u00edmbolo da letra grega min\u00fascula teta",upsih:"S\u00edmbolo da letra grega upsilon com gancho",piv:"S\u00edmbolo grego pi",bull:"marcador\npequeno c\u00edrculo preto",hellip:"retic\u00eancias horizontais\ntr\u00eas pontos",
prime:"prim\u00e1rio\nminutos\np\u00e9s",Prime:"prim\u00e1rio duplo\nsegundos\npolegadas",oline:"sobrelinha\nlinha sobreposta de espa\u00e7amento",frasl:"barra de fra\u00e7\u00e3o",weierp:"script com letra P mai\u00fascula\nconjunto de pot\u00eancias\nWeierstrass p",image:"letra I mai\u00fascula g\u00f3tica\nparte imagin\u00e1ria",real:"letra R mai\u00fascula g\u00f3tica\ns\u00edmbolo da parte real",trade:"s\u00edmbolo de marca registrada",alefsym:"s\u00edmbolo alef\nprimeiro cardinal transfinito",
larr:"seta para esquerda",uarr:"seta para cima",rarr:"seta para direita",darr:"seta para baixo",harr:"seta para esquerda e direita",crarr:"seta para baixo com curva para esquerda\nretorno de texto",lArr:"seta dupla para esquerda",uArr:"seta dupla para cima",rArr:"seta dupla para direita",dArr:"seta dupla para baixo",hArr:"seta dupla para esquerda e direita",forall:"para todos",part:"diferen\u00e7a parcial",exist:"existe pelo menos",empty:"conjunto vazio\nconjunto nulo\ndi\u00e2metro",nabla:"nabla\ndiferen\u00e7a de retr\u00f3grado",
isin:"pertence a",notin:"n\u00e3o pertence a",ni:"cont\u00e9m",prod:"produto n-ary\nsinal de produto",sum:"somat\u00f3rio de n elementos",minus:"sinal de menos",lowast:"asterisco",radic:"raiz quadrada\nsinal de radical",prop:"proporcional a",infin:"infinito",ang:"\u00e2ngulo",and:"l\u00f3gica e\nfor\u00e7a",or:"l\u00f3gica ou\nvee",cap:"limite de\nintersec\u00e7\u00e3o",cup:"uni\u00e3o\ncopa","int":"integral",there4:"para isso",sim:"operador de til\nvaria com\nsemelhante a",cong:"aproximadamente igual a",
asymp:"quase igual a\nassint\u00f3tico a",ne:"diferente de",equiv:"id\u00eantico a",le:"menor ou igual a",ge:"maior ou igual a",sub:"est\u00e1 contido em",sup:"cont\u00e9m",nsub:"n\u00e3o est\u00e1 contido em",sube:"est\u00e1 contido ou \u00e9 igual a",supe:"cont\u00e9m ou \u00e9 igual a",oplus:"circulado mais\nsoma direta",otimes:"vezes circulado\nproduto de vetor",perp:"desvio para cima\nortogonal para\nperpendicular",sdot:"ponto de multiplica\u00e7\u00e3o",lceil:"teto esquerdo\nlance vertical APL",
rceil:"chave em L com o canto voltado para cima \u00e0 direita",lfloor:"piso esquerdo\nlance para baixo APL",rfloor:"chave em L com o canto voltado para baixo \u00e0 direita",lang:"sinal de maior e menor para esquerda",rang:"sinal de maior e menor para direita",loz:"losango",spades:"s\u00edmbolo de espadas",clubs:"s\u00edmbolo de\npaustrevo",hearts:"cora\u00e7\u00e3o negro\ns\u00edmbolo de copas",diams:"diamante negro",OElig:"Liga\u00e7\u00e3o latina mai\u00fascula OE",oelig:"Liga\u00e7\u00e3o latina min\u00fascula oe",
Scaron:"Letra latina mai\u00fascula S com caron",scaron:"Letra latina min\u00fascula s com caron",Yuml:"Letra latina mai\u00fascula Y com trema",circ:"Acento circunflexo",tilde:"til pequeno",ensp:"espa\u00e7o simples",emsp:"espa\u00e7o duplo",thinsp:"espa\u00e7o estreito",zwnj:"separador de largura zero",zwj:"conector de largura zero",lrm:"marca da esquerda para a direita",rlm:"marca da direita para a esquerda",ndash:"tra\u00e7o",mdash:"travess\u00e3o",lsquo:"aspas simples \u00e0 esquerda",rsquo:"aspas simples \u00e0 direita",
sbquo:"aspas simples inferior \u00e0 direita",ldquo:"aspas duplas inferior \u00e0 esquerda",rdquo:"aspas duplas \u00e0 direita",bdquo:"aspas duplas inferiores \u00e0 direita",dagger:"cruz",Dagger:"cruz dupla",permil:"s\u00edmbolo por mil",lsaquo:"aspa latina de encerramento",rsaquo:"aspa latina de abertura",euro:"s\u00edmbolo de euro",_localized:{}},"dojox/editor/plugins/nls/InsertEntity":{insertEntity:"Inserir S\u00edmbolo",_localized:{}},"dojo/nls/colors":{aliceblue:"azul alice",antiquewhite:"branco antigo",
aqua:"aqua",aquamarine:"\u00e1gua marinha",azure:"azul celeste",beige:"bege",bisque:"bisque",black:"preto",blanchedalmond:"am\u00eandoa pelada",blue:"azul",blueviolet:"azul violeta",brown:"marrom",burlywood:"burlywood",cadetblue:"azul cadet",chartreuse:"chartreuse",chocolate:"chocolate",coral:"coral",cornflowerblue:"azul centaurea",cornsilk:"cornsilk",crimson:"carmesim",cyan:"ciano",darkblue:"azul escuro",darkcyan:"ciano escuro",darkgoldenrod:"goldenrod escuro",darkgray:"cinza escuro",darkgreen:"verde escuro",
darkgrey:"cinza escuro",darkkhaki:"c\u00e1qui escuro",darkmagenta:"magenta escuro",darkolivegreen:"verde oliva escuro",darkorange:"laranja escuro",darkorchid:"orqu\u00eddea escuro",darkred:"vermelho escuro",darksalmon:"salm\u00e3o escuro",darkseagreen:"verde marinho escuro",darkslateblue:"azul ard\u00f3sia escuro",darkslategray:"cinza ard\u00f3sia escuro",darkslategrey:"cinza ard\u00f3sia escuro",darkturquoise:"turquesa escuro",darkviolet:"violeta escuro",deeppink:"rosa profundo",deepskyblue:"azul c\u00e9u intenso",
dimgray:"cinza turvo",dimgrey:"cinza turvo",dodgerblue:"azul dodger",firebrick:"firebrick",floralwhite:"branco floral",forestgreen:"verde floresta",fuchsia:"f\u00facsia",gainsboro:"gainsboro",ghostwhite:"branco ghost",gold:"dourado",goldenrod:"goldenrod",gray:"cinza",green:"verde",greenyellow:"amarelo esverdeado",grey:"cinza",honeydew:"honeydew",hotpink:"rosa quente",indianred:"vermelho indiano",indigo:"\u00edndigo",ivory:"marfim",khaki:"c\u00e1qui",lavender:"lavanda",lavenderblush:"lavanda avermelhada",
lawngreen:"verde grama",lemonchiffon:"lim\u00e3o chiffon",lightblue:"azul claro",lightcoral:"coral claro",lightcyan:"ciano claro",lightgoldenrodyellow:"amarelo goldenrod claro",lightgray:"cinza claro",lightgreen:"verde claro",lightgrey:"cinza claro",lightpink:"rosa claro",lightsalmon:"salm\u00e3o claro",lightseagreen:"verde marinho claro",lightskyblue:"azul c\u00e9u claro",lightslategray:"cinza ard\u00f3sia claro",lightslategrey:"cinza ard\u00f3sia claro",lightsteelblue:"azul a\u00e7o claro",lightyellow:"amarelo claro",
lime:"lima",limegreen:"verde lima",linen:"linho",magenta:"magenta",maroon:"castanho",mediumaquamarine:"\u00e1gua marinha m\u00e9dio",mediumblue:"azul m\u00e9dio",mediumorchid:"orqu\u00eddea m\u00e9dio",mediumpurple:"roxo m\u00e9dio",mediumseagreen:"verde marinho m\u00e9dio",mediumslateblue:"azul ard\u00f3sia m\u00e9dio",mediumspringgreen:"verde primavera m\u00e9dio",mediumturquoise:"turquesa m\u00e9dio",mediumvioletred:"vermelho violeta m\u00e9dio",midnightblue:"azul meia-noite",mintcream:"creme de menta",
mistyrose:"rosa enevoado",moccasin:"moccasin",navajowhite:"branco navajo",navy:"marinho",oldlace:"cadar\u00e7o velho",olive:"oliva",olivedrab:"verde oliva",orange:"laranja",orangered:"vermelho alaranjado",orchid:"orqu\u00eddea",palegoldenrod:"goldenrod esbranqui\u00e7ado",palegreen:"verde esbranqui\u00e7ado",paleturquoise:"turquesa esbranqui\u00e7ado",palevioletred:"vermelho violeta esbranqui\u00e7ado",papayawhip:"creme de papaya",peachpuff:"peach puff",peru:"peru",pink:"rosa",plum:"ameixa",powderblue:"azul talco",
purple:"roxo",red:"vermelho",rosybrown:"marrom rosado",royalblue:"azul royal",saddlebrown:"marrom saddle",salmon:"salm\u00e3o",sandybrown:"marrom cor de areia",seagreen:"verde marinho",seashell:"seashell",sienna:"sienna",silver:"prateado",skyblue:"azul c\u00e9u",slateblue:"azul ard\u00f3sia",slategray:"cinza ard\u00f3sia",slategrey:"cinza ard\u00f3sia",snow:"branco neve",springgreen:"verde primavera",steelblue:"azul a\u00e7o",tan:"tan",teal:"azul esverdeado",thistle:"thistle",tomato:"tomate",transparent:"transparente",
turquoise:"turquesa",violet:"violeta",wheat:"trigo",white:"branco",whitesmoke:"fuma\u00e7a branca",yellow:"amarelo",yellowgreen:"verde amarelado",_localized:{}},"dojox/widget/nls/ColorPicker":{redLabel:"r",greenLabel:"g",blueLabel:"b",hueLabel:"h",saturationLabel:"s",valueLabel:"v",degLabel:"\u00b0",hexLabel:"hex",huePickerTitle:"Seletor de Matiz",saturationPickerTitle:"Seletor de Satura\u00e7\u00e3o",_localized:{}},"dojox/editor/plugins/nls/TableDialog":{insertTableTitle:"Inserir Tabela",modifyTableTitle:"Modificar Tabela",
rows:"Linhas:",columns:"Colunas:",align:"Alinhar:",cellPadding:"Preenchimento de C\u00e9lula:",cellSpacing:"Espa\u00e7amento de C\u00e9lula:",tableWidth:"Largura da Tabela:",backgroundColor:"Cor do Plano de Fundo:",borderColor:"Cor da Borda:",borderThickness:"Espessura da Borda:",percent:"percentual",pixels:"pixels","default":"default",left:"esquerda",center:"centro",right:"direita",buttonSet:"Configurar",buttonInsert:"Inserir",buttonCancel:"Cancelar",selectTableLabel:"Selecionar Tabela",insertTableRowBeforeLabel:"Incluir Linha Antes",
insertTableRowAfterLabel:"Incluir Linha Depois",insertTableColumnBeforeLabel:"Incluir Coluna Antes",insertTableColumnAfterLabel:"Incluir Coluna Depois",deleteTableRowLabel:"Excluir Linha",deleteTableColumnLabel:"Excluir Coluna",colorTableCellTitle:"C\u00e9lula de Tabela de Cor do Segundo Plano",tableContextMenuTitle:"Menu de Contexto da Tabela",_localized:{}},"dojox/editor/plugins/nls/PasteFromWord":{pasteFromWord:"Colar do Word",instructions:"Cole o conte\u00fado do Word na caixa de texto a seguir. Quando estiver satisfeito com o conte\u00fado a ser inserido, pressione o bot\u00e3o para colar. Para interromper a inser\u00e7\u00e3o de texto, pressione o bot\u00e3o para cancelar.",
_localized:{}},"dojox/editor/plugins/nls/InsertAnchor":{insertAnchor:"Inserir \u00c2ncora",title:"Propriedades de \u00c2ncora",anchor:"Nome:",text:"Descri\u00e7\u00e3o:",set:"Configurar",cancel:"Cancelar",_localized:{}},"dojox/editor/plugins/nls/Blockquote":{blockquote:"Cita\u00e7\u00e3o de Bloco",_localized:{}},"dojox/editor/plugins/nls/LocalImage":{insertImageTitle:"Inserir imagem",url:"Imagem",browse:"Procurar...",text:"Descri\u00e7\u00e3o",set:"Inserir",invalidMessage:"Tipo de arquivo de imagem inv\u00e1lido",
prePopuTextUrl:"Insira uma URL de imagem",prePopuTextBrowse:" ou navegue at\u00e9 um arquivo local.",_localized:{}}});
//# sourceMappingURL=pmbdojo_pt-br.js.map